/*
 * #%L
 * JavaHg
 * %%
 * Copyright (C) 2011 aragost Trifork ag
 * %%
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * #L%
 */
package com.aragost.javahg.commands;

import com.aragost.javahg.Changeset;

/**
 * An annotated line, holding the text of the line and the
 * {@link Changeset} that introduced it.
 */
public class AnnotateLine {

    private Changeset changeset;
    private String line;

    /**
     * @param changeset
     *            a changeset.
     * @param line
     *            a single line of text.
     */
    public AnnotateLine(Changeset changeset, String line) {
        if (changeset == null || line == null) {
            throw new NullPointerException("changeset or line is null");
        }
        this.changeset = changeset;
        this.line = line;
    }

    /**
     * @return the changeset.
     */
    public Changeset getChangeset() {
        return changeset;
    }

    /**
     * @deprecated use getChangeset()
     * @return
     */
    @Deprecated
    public Changeset getChangeSet() {
        return getChangeset();
    }

    /**
     * @return the line of text.
     */
    public String getLine() {
        return line;
    }

    @Override
    public String toString() {
        return getChangeset().toString() + ":" + getLine();
    }
}
