/*
 * #%L
 * JavaHg
 * %%
 * Copyright (C) 2011 aragost Trifork ag
 * %%
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * #L%
 */
package com.aragost.javahg.commands;

import java.io.File;
import java.util.List;

import com.aragost.javahg.Changeset;
import com.aragost.javahg.Repository;
import com.aragost.javahg.commands.flags.OutgoingCommandFlags;

/**
 * Command class for executing <tt>hg outgoing</tt>. Set flags from
 * {@link OutgoingCommandFlags} and call the {@link #execute} method.
 */
public class OutgoingCommand extends OutgoingCommandFlags {

    /**
     * @param repository
     *            the repository associated with this command.
     */
    public OutgoingCommand(Repository repository) {
        super(repository);
        withDebugAndChangesetStyle();
    }

    /**
     * @param dst
     *            the destination repository.
     * @return list of outgoing changesets.
     */
    public List<Changeset> execute(String dst) {
        return Changeset.readListFromStream(getRepository(), launchStream(dst));
    }

    public List<Changeset> execute(File repoDir) {
        return execute(repoDir.getPath());
    }

    public List<Changeset> execute(Repository repository) {
        return execute(repository.getDirectory());
    }

    @Override
    public boolean isSuccessful() {
        return super.isSuccessful() || getReturnCode() == 1;
    }
}
