/*
 * #%L
 * JavaHg
 * %%
 * Copyright (C) 2011 aragost Trifork ag
 * %%
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * #L%
 */
package com.aragost.javahg.commands;

import com.aragost.javahg.HgVersion;
import com.aragost.javahg.Repository;
import com.aragost.javahg.commands.flags.VersionCommandFlags;
import com.aragost.javahg.internals.UnexpectedCommandOutputException;

/**
 * Command class for executing <tt>hg version</tt>. Set flags from
 * {@link VersionCommandFlags} and call the {@link #execute} method.
 */
public class VersionCommand extends VersionCommandFlags {

    private static final String PREFIX = "Mercurial Distributed SCM (version ";

    /**
     * @param repository
     *            the repository associated with this command.
     */
    public VersionCommand(Repository repository) {
        super(repository);
    }

    /**
     * Retrieve the Mercurial version number.
     * 
     * @return the Mercurial version of the command server. This is a
     *         string since it can include extra information such as
     *         the exact changeset ID used to build Mercurial.
     */
    public HgVersion execute() {
        String s = launchString();
        if (s.startsWith(PREFIX)) {
            s = s.substring(PREFIX.length());
            int n = s.indexOf(')');
            return HgVersion.fromString(new String(s.substring(0, n)));
        } else {
            throw new UnexpectedCommandOutputException(this, s);
        }
    }

}
