package com.aragost.javahg.internals;

import java.io.File;
import java.util.Map;

import com.aragost.javahg.Repository;
import com.google.common.annotations.VisibleForTesting;
import com.google.common.collect.Maps;

public class CopyRenameHelper {

    public static Map<File, File> parse(Repository repo, File[] files, LineIterator output, String prefix){
        Map<File, File> result = Maps.newHashMap();
        // Assume multiple source files by default, in which case the
        // destination must be a directory.
        boolean dstIsDirectory = true;
        if (files.length == 2) {
            dstIsDirectory = files[1].isDirectory();
        }

        // Make all files relative to repository
        for (int i = 0; i < files.length; i++) {
            File file = files[i];
            files[i] = repo.relativeFile(file);
        }

        int currentSrc = 0;
        File src = files[currentSrc];
        File dst = files[files.length - 1];
        for (String line : output) {
            if (line.startsWith(prefix)) {
                if (!line.substring(prefix.length()).startsWith(src.getPath())) {
                    currentSrc++;
                    src = files[currentSrc];
                }
                String[] names = CopyRenameHelper.parseCopyLine(src.getPath(), dst.getPath(), line, dstIsDirectory, prefix);
                result.put(new File(names[1]), new File(names[0]));
            } else {
                throw new UnexpectedCommandOutputException("could not parse '" + line + "'");
            }
        }
        return result;

    }
    
    @VisibleForTesting
    public static String[] parseCopyLine(String src, String dst, String line, boolean dstIsDirectory, String prefix) {
        if (src.charAt(src.length() - 1) == File.separatorChar) {
            src = src.substring(0, src.length() - 1);
        }
        if (dst.charAt(dst.length() - 1) == File.separatorChar) {
            dst = dst.substring(0, dst.length() - 1);
        }
    
        line = line.substring(prefix.length()).trim();
    
        int lineLength = line.length();
        int srcLength = src.length();
        int dstLength = dst.length();
    
        boolean srcIsDirectory = line.charAt(srcLength) == File.separatorChar;
    
        if (dstIsDirectory) {
            dstLength += 1;
        }
        if (srcIsDirectory) {
            srcLength += 1;
        }
    
        int pathLength = lineLength - 4 - srcLength - dstLength;
        if (dstIsDirectory) {
            pathLength -= srcLength;
        }
        if (pathLength % 2 != 0) {
            throw new IllegalStateException("pathLength not even");
        }
        pathLength /= 2;
    
        String oldName = line.substring(0, srcLength + pathLength);
        String newName = line.substring(srcLength + pathLength + 4, lineLength);
        return new String[] { oldName, newName };
    }

}
